﻿using System;
using ELTE.Calculator.Device;
using Xamarin.Forms;

namespace ELTE.Calculator.View
{
    /// <summary>
    /// Tájolással kapcsolatos viselkedés vezérlőkre.
    /// </summary>
    public class ViewOrientationBehavior : Behavior<Xamarin.Forms.View>
    {
        private IDeviceProperties _properties;

        public ViewOrientationBehavior()
        {
            // lekérjük a függőség megfelelő megvalósítását
            _properties = DependencyService.Get<IDeviceProperties>();
        }

        protected override void OnAttachedTo(Xamarin.Forms.View bindable)
        {
            // feliratkozunk a méretváltozás eseményére
            bindable.SizeChanged += new EventHandler(Bindable_SizeChanged);

            // meg kell hívnunk az ős metódusát is
            base.OnAttachedTo(bindable);
        }

        protected override void OnDetachingFrom(Xamarin.Forms.View bindable)
        {
            // leiuratkozunk a méretváltozás eseményéről
            bindable.SizeChanged -= Bindable_SizeChanged;

            base.OnDetachingFrom(bindable);
        }

        private void Bindable_SizeChanged(object sender, EventArgs e)
        {
            if (_properties == null)
                return; // ha az adott platformon nem érhető el a függőség, nem csinálunk semmit

            Xamarin.Forms.View view = sender as Xamarin.Forms.View;

            // az eszköz tájolásának függvényében változtatunk a vezérlő elhelyezkedésén
            switch (_properties.DeviceOrientation)
            {
                case DeviceOrientation.Landscape:
                    if (!view.HorizontalOptions.Equals(LayoutOptions.Fill))
                        view.HorizontalOptions = LayoutOptions.Fill;
                    break;
                case DeviceOrientation.Portrait:
                    if (!view.HorizontalOptions.Equals(LayoutOptions.CenterAndExpand))
                        view.HorizontalOptions = LayoutOptions.CenterAndExpand;
                    break;
            }
        }

    }
}
